@@ -25,7 +25,7 @@ suggest_levels <-
     if(recode==TRUE & maxlevels>26) { stop("Can recode into a max of 26 levels") }
     
     #Make sure y is the right type of variable
-    if( !( class(y) %in% c("integer","numeric") ) ) { 
+    if( !( head(class(y),1) %in% c("integer","numeric") ) ) { 
       y <- factor(y) 
       if( length(levels(y)) > 2 ) { stop("Error:  y should only have two possible values.") } 
     }
@@ -37,15 +37,15 @@ suggest_levels <-
     if( length(unique(x)) < 2 | length(unique(y)) < 2) { stop(paste("Error:  need at least 2 unique values to proceed.")) }
     
     
-    if (class(y) %in% c("numeric","integer")) { TAB <- aggregate(y~x,FUN=mean) }
-    if (class(y) == "factor" ) {  TAB <- aggregate(y~x,FUN=function(x)mean(x==levels(x)[1])) }
+    if (head(class(y),1) %in% c("numeric","integer")) { TAB <- aggregate(y~x,FUN=mean) }
+    if (head(class(y),1) == "factor" ) {  TAB <- aggregate(y~x,FUN=function(x)mean(x==levels(x)[1])) }
     
     TAB <- TAB[order(TAB$y),]
 
     PART <- rpart(y~x,data=TAB,control=rpart.control(cp=0,minbucket=1,minsplit = 1))
     
-    if( class(y) %in% c("numeric","integer") ) { BIC <- BIC(lm(y~1)) }
-    if( class(y) == "factor" )  { BIC <- BIC(glm(y~1,family=binomial)) }
+    if( head(class(y),1) %in% c("numeric","integer") ) { BIC <- BIC(lm(y~1)) }
+    if( head(class(y),1) == "factor" )  { BIC <- BIC(glm(y~1,family=binomial)) }
     
     if(missing(maxlevels)) { maxlevels <- nrow(TAB) }
     
@@ -63,8 +63,8 @@ suggest_levels <-
 
       BIC.table$clusters[tree] <- paste("(",paste(clustID, collapse=")("),")",sep="")
       
-      if( class(y) %in% c("numeric","integer") ) { BIC.table$BIC[tree] <- BIC(lm(y~x.temp)) }
-      if( class(y) == "factor" )  { BIC.table$BIC[tree] <- BIC(glm(y~x.temp,family=binomial)) }
+      if( head(class(y),1) %in% c("numeric","integer") ) { BIC.table$BIC[tree] <- BIC(lm(y~x.temp)) }
+      if( head(class(y),1) == "factor" )  { BIC.table$BIC[tree] <- BIC(glm(y~x.temp,family=binomial)) }
     }
       
    suggested <- min( which(BIC.table$BIC <= ( min(BIC.table$BIC) + 5 ) ) )
@@ -80,7 +80,7 @@ suggest_levels <-
    xx <- factor(x,levels=as.character( TAB$x ), ordered=TRUE )
 
   DF <- data.frame(y=y,xx=xx)
-   if(class(y)=="factor") {
+   if(head(class(y),1)=="factor") {
      if(plot==TRUE) { mosaic(y~xx,data=DF,...) }
     if(suggested>1) {
      ID <- prune(PART,cp=PART$cptable[suggested,1])$where
@@ -91,7 +91,7 @@ suggest_levels <-
 
          
 
-   if(class(y)%in%c("numeric","integer") ) {
+   if(head(class(y),1)%in%c("numeric","integer") ) {
      if(plot==TRUE) { plot(y~xx,xlab=x.label,ylab=y.label,...) }
      if(suggested>1) {
        ID <- prune(PART,cp=PART$cptable[suggested,1])$where
